package com.kuyuntech.cofarcooking.device.sdk.protocol.core;


import com.kuyuntech.cofarcooking.device.sdk.util.core.Converter;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@AllArgsConstructor
public class BaseBody {

    //帧头
    private byte header = 0x7e;

    //数据长度
    private byte length;

    //数据内容
    private byte[] content;

    //校验和
    private byte check;

    //结尾
    private byte footer = 0x7e;

    public BaseBody(){

    }

    public BaseBody(byte[] content) {
        this.content = content;
        this.length = (byte) (this.content.length + 4);
        this.check = this.check();
    }


    private byte check(){
        int sum = 0;
        sum += this.length;
        for (byte b : content) {
            sum+=b;
        }
        return (byte) sum;
    }

    public BaseBody(String content) {
        this(Converter.hexStringToBytes(content));
    }




    public byte[] escapeBytes(){
        StringBuilder temp = new StringBuilder();

        //转义
        temp.append(Converter.getHexString(new byte[]{header},1));
        temp.append(Converter.getHexString(new byte[]{length},1));
        for (byte tempByte : this.content) {

            if(tempByte == 0x7e){
                temp.append("7d02");
            }else if(tempByte == 0x7d){
                temp.append("7d01");
            }else{
                temp.append(Converter.bytesToHexString(new byte[]{tempByte},1));
            }
        }
        temp.append(Converter.getHexString(new byte[]{check},1));
        temp.append(Converter.getHexString(new byte[]{footer},1));
        return Converter.hexStringToBytes(temp.toString());
    }

    public String escapeBytesStr(){
        byte[] data = this.escapeBytes();
        return Converter.bytesToHexString( data,data.length);
    }


    public  byte[] bytes(){
        StringBuilder temp = new StringBuilder();

        //转义
        temp.append(Converter.getHexString(new byte[]{header},1));
        temp.append(Converter.getHexString(new byte[]{length},1));
        for (byte tempByte : this.content) {
            temp.append(Converter.bytesToHexString(new byte[]{tempByte},1));
        }
        temp.append(Converter.getHexString(new byte[]{check},1));
        temp.append(Converter.getHexString(new byte[]{footer},1));
        return Converter.hexStringToBytes(temp.toString());
    }

    public  String bytesStr(){
        byte[] data = this.bytes();
        return Converter.bytesToHexString(data,data.length);
    }

}
